@@ -2,27 +2,29 @@
 //! Generate Database Methods.
 //! 
 use proc_macro::TokenStream;
-
+use proc_macro_error::{ proc_macro_error};
 
 #[macro_use]
 mod table_derive;
 #[macro_use]
 mod convert_derive;
+mod util;
+mod comm;
 
 
-// #[proc_macro_derive(Table, attributes(column, table, id, exist))]
+// #[proc_macro_derive(AkitaTable, attributes(column, table, id, exist))]
 // pub fn table(input: TokenStream) -> TokenStream {
 //     table_derive::impl_to_table(input)
 // }
 
 /// Generate table info data
-#[proc_macro_derive(FromAkita)]
+#[proc_macro_derive(FromValue)]
 pub fn from_akita(input: TokenStream) -> TokenStream {
     convert_derive::impl_from_akita(input)
 }
 
 /// Format table info data
-#[proc_macro_derive(ToAkita)]
+#[proc_macro_derive(ToValue)]
 pub fn to_akita(input: TokenStream) -> TokenStream {
     convert_derive::impl_to_akita(input)
 }
@@ -30,7 +32,7 @@ pub fn to_akita(input: TokenStream) -> TokenStream {
 /// Generate table info
 /// ```rust
 /// /// Annotion Support: Table、table_id、field (name, exist)
-/// #[derive(Debug, FromAkita, ToAkita, Table, Clone)]
+/// #[derive(Debug, FromValue, ToValue, AkitaTable, Clone)]
 /// #[table(name="t_system_user")]
 /// struct SystemUser {
 ///     #[field = "name"]
@@ -42,19 +44,8 @@ pub fn to_akita(input: TokenStream) -> TokenStream {
 /// }
 /// ```
 /// 
-#[proc_macro_derive(Table, attributes(field, table, table_id))]
+#[proc_macro_derive(AkitaTable, attributes(field, table, table_id, fill))]
+#[proc_macro_error]
 pub fn to_table(input: TokenStream) -> TokenStream {
     table_derive::impl_get_table(input)
-}
-
-/// Generate table name
-#[proc_macro_derive(GetTableName)]
-pub fn to_table_name(input: TokenStream) -> TokenStream {
-    table_derive::impl_get_table_name(input)
-}
-
-/// Generate table fields
-#[proc_macro_derive(GetFields)]
-pub fn to_column_names(input: TokenStream) -> TokenStream {
-    table_derive::impl_get_column_names(input)
 }
\ No newline at end of file
